#!perl -w

use strict;
use Test::More tests => 8;

use_ok("Data::Microformat");
use_ok("Data::Microformat::adr");
use_ok("Data::Microformat::geo");
use_ok("Data::Microformat::hCard::type");
use_ok("Data::Microformat::hCard::name");
use_ok("Data::Microformat::hCard::organization");
use_ok("Data::Microformat::hFeed::hEntry");
use_ok("Data::Microformat::hFeed");

